pub struct UniswapV3SwapRouterInstance<P, N = Ethereum> { /* private fields */ }Expand description
A UniswapV3SwapRouter instance.
Contains type-safe methods for interacting with an on-chain instance of the
UniswapV3SwapRouter contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain UniswapV3SwapRouter contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> UniswapV3SwapRouterInstance<&P, N>
impl<P: Clone, N> UniswapV3SwapRouterInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> UniswapV3SwapRouterInstance<P, N>
pub fn with_cloned_provider(self) -> UniswapV3SwapRouterInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn exactInputSingle(
&self,
params: <ExactInputSingleParams as SolType>::RustType,
) -> SolCallBuilder<&P, exactInputSingleCall, N>
pub fn exactInputSingle( &self, params: <ExactInputSingleParams as SolType>::RustType, ) -> SolCallBuilder<&P, exactInputSingleCall, N>
Creates a new call builder for the [exactInputSingle] function.
Sourceimpl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> UniswapV3SwapRouterInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.